@@ -538,6 +538,35 @@ Arnolfini.carouselFix = function ()
 	$("#MainContent").css("background-image", "none");
 }
 
+
+Arnolfini.trackEcommerce = function ()
+{
+	
+}
+
+Arnolfini.sendPaypalTrack = function (title, price)
+{
+	_gaq.push(['_addTrans',
+	   encodeURIComponent(title),           // transaction ID - required
+	   'Arnolfini', // affiliation or store name
+	   price.toString(),          // total - required
+	   '',           // tax
+	   '',          // shipping
+	   '',       // city
+	   '',     // state or province
+	   ''      // country
+	]);
+	_gaq.push(['_addItem',
+	   encodeURIComponent(title),           // transaction ID - necessary to associate item with transaction
+	   '',           // SKU/code - required
+	   title,        // product name
+	   '',   // category or variation
+	   price.toString(),          // unit price - required
+	   '1'               // quantity - required
+	]);
+	_gaq.push(['_trackTrans']);
+}
+
 $(document).ready(function() {
 	$('#portal-globalnav li a').removeAttr('title');
 	setTimeout(Arnolfini.carouselFix, 1000);
@@ -587,5 +616,7 @@ $(document).ready(function() {
 		viewport = document.querySelector("meta[name=viewport]");  
 		viewport.setAttribute('content', "width=777, initial-scale=0.3");  
 	}
+	
+	Arnolfini.trackEcommerce();
 });
 
