@@ -105,7 +105,7 @@ class CommonBrowserView(BrowserView):
                 <input name="no-shipping" type="hidden" value="1" />
                 <input name="currency_code" type="hidden" value="GBP" />
                 <input name="cpp_header_image" type="hidden" value="http://new.arnolfini.org.uk/++resource++plonetheme.arnolfini.images/arnolfiniLogo.png" />
-                <input name="return" type="hidden" value="http://new.arnolfini.org.uk/about/support/thank-you/" />
+                <input name="return" type="hidden" value="http://www.arnolfini.org.uk/purchase/thank-you/" />
                 <input name="cmd" type="hidden" value="_xclick" />
                 <input type="submit" value="%(label)s" />
             </form>
